QdAnnealingExecutor - Qudas 0.2.0 documentation

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Toggle table of contents sidebar

# QdAnnealingExecutor

class qudas.annealing.executor.QdAnnealingExecutor(provider: str = 'default', provider_config: Dict[str, Any] | None = None, provider_map: Dict[str, str] | None = None, provider_config_map: Dict[str, Dict[str, Any]] | None = None)

  Bases: `QdExecutorBase`

  複数デバイスへの並列実行をサポートするアニーリング用 Executor。

  run(input_data: QdAnnealingInput) → QdAnnealingOutput

    単一の `QdAnnealingInput` を実行し、 `QdAnnealingOutput` を返却。

    Parameters:

      input_data (QdAnnealingInput) – 実行対象の量子アニーリングブロックを含む入力。

    Returns:

      ブロック名をキー、各 backend の実行結果を値とする辞書を `results` として保持します。

    Return type:

      QdAnnealingOutput

  run_split(input_data: QdAnnealingInput) → QdAnnealingOutput

    与えられた複数ブロックを並列実行し、結果を `QdAnnealingOutput` で返却。

    Parameters:

      input_data (QdAnnealingInput) – 実行対象の量子アニーリングブロックを含む入力。

    Returns:

      ブロック名をキー、各 backend の実行結果を値とする辞書を `results` として保持します。

    Return type:

      QdAnnealingOutput